#
# spec file for package deepin-file-manager
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name dde-file-manager
%define sover 5

Name:           deepin-file-manager
Version:        5.6.4
Release:        3.10
Summary:        Deepin File Manager
License:        GPL-3.0-or-later AND MIT
Group:          Productivity/File utilities
URL:            https://github.com/linuxdeepin/dde-file-manager
Source0:        https://github.com/linuxdeepin/dde-file-manager/archive/%{version}/%{_name}-%{version}.tar.gz
Source1:        deepin-file-dbus-installer.in
Source2:        deepin-file-polkit-installer.in
# PATCH-FIX-UPSTEAM fix-header-include.patch hillwood@opensuse.org - dfsearch is necessary
Patch1:         fix-header-include.patch
# PATCH-FIX-UPSTEAM gcc12.patch hillwood@opensuse.org - fix gcc 12 build
Patch2:         gcc-12.patch
Patch3:         harden_dde-filemanager-daemon.service.patch
%ifarch ppc ppc64 ppc64le s390 s390x
BuildRequires:  deepin-desktop-base
%else
BuildRequires:  deepin-manual
%endif
BuildRequires:  boost-devel
BuildRequires:  deepin-gettext-tools
BuildRequires:  dtkcore
BuildRequires:  fdupes
BuildRequires:  file-devel
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5PlatformHeaders-devel
BuildRequires:  libQt5Widgets-private-headers-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libmimetic-devel
BuildRequires:  libqt5-linguist
BuildRequires:  pcre-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  udisks2-qt5-devel >= 5.0.0
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Codecs)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5MultimediaWidgets)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xdg)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(dde-dock)
BuildRequires:  pkgconfig(dframeworkdbus)
BuildRequires:  pkgconfig(disomaster)
BuildRequires:  pkgconfig(docparser)
BuildRequires:  pkgconfig(dtkwidget)
BuildRequires:  pkgconfig(dtkwm)
BuildRequires:  pkgconfig(gio-qt)
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(htmlcxx)
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libdmr)
BuildRequires:  pkgconfig(libffmpegthumbnailer)
BuildRequires:  pkgconfig(libgsf-1)
BuildRequires:  pkgconfig(liblucene++)
BuildRequires:  pkgconfig(libmediainfo)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(polkit-qt5-1)
BuildRequires:  pkgconfig(poppler-cpp)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(uchardet)
BuildRequires:  pkgconfig(udisks2)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xcb-util)
Requires:       deepin-shortcut-viewer
Requires:       deepin-terminal
Requires:       file-roller
Requires:       glib2-tools
Requires:       gstreamer-plugins-good
Requires:       gvfs
Requires:       libqt5-dxcbplugin
Requires:       libqt5-qdbus
Requires:       qt5integration
Requires:       samba
Requires:       xdg-user-dirs
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_ordering}

%description
Deepin File Manager is a file management tool independently  developed by Deepin
Technology, featured with searching, copying, trash, compression/decompression,
file property and other file management functions.

%package -n deepin-desktop
Summary:        Deepin Desktop
Group:          System/GUI/Other

%description -n deepin-desktop
Deepin desktop environment - desktop module.

%package -n lib%{_name}%{sover}
Summary:        Deepin File Manager libraries
Group:          System/Libraries

%description -n lib%{_name}%{sover}
This package contains the libraries for deepin-file-manager

%package -n libdfm-extension%{sover}
Summary:        Deepin File Manager libraries
Group:          System/Libraries

%description -n libdfm-extension%{sover}
This package contains the libraries for deepin-file-manager

%package polkit
Summary:        Deepin File polkit profiles
Group:          Productivity/File utilities
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
AutoReqProv:    Off

%description polkit
This package provides polkit profiles for deepin-file-manager. These profiles
are not adopted by security team. If you need the polkit feature, you should
install them manually or use deepin-polkit-install package.

%package dbus
Summary:        Deepin File DBus profiles
Group:          Productivity/File utilities
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
AutoReqProv:    Off

%description dbus
This package provides dbus profiles for deepin-file-manager. These profiles are
not adopted by security team. If you need the dbus feature, you should install
them manually or use deepin-dbus-install package.

%package devel
Summary:        Development package for Deepin File Manager
Group:          Development/Libraries/X11
Requires:       lib%{_name}%{sover} = %{version}

%description devel
Header files and libraries for Deepin File Manager.

%lang_package

%prep
%autosetup -p1 -n %{_name}-%{version}

find -type f -perm 775 -exec chmod 644 {} \;
find -type f -name ".readme" -delete -print
sed -i '/target.path/s|$${PREFIX}/lib|$$LIBDIR|' src/dde-dock-plugins/disk-mount/disk-mount.pro

sed -i 's|lrelease|lrelease-qt5|' src/%{_name}/generate_translations.sh \
src/%{_name}-*/generate_translations.sh \
src/dde-desktop/translate_generation.sh

sed -i 's|lupdate|lupdate-qt5|' src/%{_name}*/update_translations.sh \
src/dde-desktop/update_translations.sh \
src/dde-dock-plugins/disk-mount/update_translations.sh

sed -i '/target.path/s|lib|%{_lib}|' src/dde-dock-plugins/disk-mount/disk-mount.pro

sed -i 's|qdbus|qdbus-qt5|g' tests/dde-file-manager-lib/dbus/ut_dbussystemInfo_test.cpp

sed -i 's|qdbusxml2cpp|qdbusxml2cpp-qt5|g' src/dde-file-manager-daemon/dbusservice/help.sh \
src/dde-file-manager-daemon/dbusservice/vault.sh

sed -i 's|qdbuscpp2xml|qdbuscpp2xml-qt5|g' src/dde-file-manager-daemon/dbusservice/vault.sh

# --as-needed link option
sed -i '/PKGCONFIG +=/s|$| x11 liblucene++|' src/%{_name}-lib/%{_name}-lib.pro

# sed -i 's/dframeworkdbus/dframeworkdbus liblucene++/g;s/-lKF5Codecs/-lKF5Codecs -llucene++/g' src/dde-file-manager-lib/dde-file-manager-lib.pro

cp 3rdparty/fsearch/* src/dde-file-manager-lib/search/
# sed -i 's|fsearch.h|../../../3rdparty/fsearch/fsearch.h|g' src/dde-file-manager-lib/search/dfsearch.h

%build

qmake-qt5 \
        PREFIX=%{_prefix} \
        LIBDIR=%{_libdir} \
        CONFIG+="DISABLE_ANYTHING" \
        IS_PLATFORM_OPENSUSE=YES \
        VERSION=%{version} \
        filemanager.pro
%make_build

%install
%qmake5_install

chmod -x %{buildroot}%{_datadir}/deepin-manual/manual-assets/application/dde-file-manager/file-manager/common/*.svg \
         %{buildroot}%{_datadir}/deepin-manual/manual-assets/application/dde-file-manager/file-manager/*/*.md

install -m0755 %{SOURCE1} %{buildroot}%{_bindir}/deepin-file-dbus-installer
install -m0755 %{SOURCE2} %{buildroot}%{_bindir}/deepin-file-polkit-installer

# Fix values extending the format should start with "X-" rpmlint warnings
sed -i 's/OnlyShowIn=/X-DEEPIN-OnlyShowIn=/g' \
        %{buildroot}%{_datadir}/applications/dde-computer.desktop \
        %{buildroot}%{_datadir}/applications/dde-trash.desktop

# Remove zero-length files
rm -rf %{buildroot}%{_datadir}/dde-file-manager/mimetypes/audio.mimetype \
        %{buildroot}%{_datadir}/dde-file-manager/mimetypes/image.mimetype

# File all dbus service and policy profiles, workaround boo#1134132 and boo#1134131
mkdir build
pushd build
mkdir polkit
mv %{buildroot}%{_datadir}/polkit-1/actions/* polkit/
tar -cvf polkit.tar.gz polkit
install -m 0644 polkit.tar.gz %{buildroot}%{_datadir}/%{_name}/

mkdir dbus
mkdir dbus/system-services
mkdir dbus/system.d
mv %{buildroot}%{_datadir}/dbus-1/system-services/* dbus/system-services
mv %{buildroot}%{_sysconfdir}/dbus-1/system.d/* dbus/system.d
tar -cvf dbus.tar.gz dbus
install -m 0644 dbus.tar.gz %{buildroot}%{_datadir}/%{_name}/
popd

install -d %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcdde-filemanager-daemon

chmod -x %{buildroot}%{_datadir}/dbus-1/services/*.service
%suse_update_desktop_file -r %{_name} System FileManager
%suse_update_desktop_file -r dde-computer System FileManager
%suse_update_desktop_file -r dde-trash System FileManager

%fdupes %{buildroot}%{_datadir}

%pre
%service_add_pre dde-filemanager-daemon.service

%post
%service_add_post dde-filemanager-daemon.service

%preun
%service_del_preun dde-filemanager-daemon.service

%postun
%service_del_postun dde-filemanager-daemon.service

%post -n lib%{_name}%{sover} -p /sbin/ldconfig
%postun -n lib%{_name}%{sover} -p /sbin/ldconfig

%post -n libdfm-extension%{sover} -p /sbin/ldconfig
%postun -n libdfm-extension%{sover} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc README.md CHANGELOG.md
%license LICENSE LICENSE.MIT
# %config(noreplace) %{_sysconfdir}/dbus-1/system.d/com.deepin.filemanager.daemon.conf
%{_prefix}/lib/systemd/system/dde-filemanager-daemon.service
%{_bindir}/*
%exclude %{_bindir}/dde-desktop
%exclude %{_bindir}/deepin-file-dbus-installer
%exclude %{_bindir}/deepin-file-polkit-installer
%{_sbindir}/rcdde-filemanager-daemon
%dir %{_libdir}/dde-dock
%dir %{_libdir}/dde-dock/plugins
%dir %{_libdir}/dde-dock/plugins/system-trays/
%{_libdir}/dde-dock/plugins/system-trays/libdde-disk-mount-plugin.so
%{_libdir}/%{_name}/
%{_datadir}/%{_name}/
%{_datadir}/deepin-manual/manual-assets/application/%{_name}
%exclude %{_datadir}/%{_name}/*.tar.gz
%{_datadir}/icons/hicolor/scalable/apps/*.svg
# %{_datadir}/deepin/dde-file-manager
%{_datadir}/dbus-1/interfaces/com.deepin.filemanager.filedialog.xml
%{_datadir}/dbus-1/interfaces/com.deepin.filemanager.filedialogmanager.xml
%{_datadir}/dbus-1/services/*.service
# %{_datadir}/dbus-1/system-services/com.deepin.filemanager.daemon.service
# %{_datadir}/polkit-1/actions/com.deepin.pkexec.dde-file-manager.policy
# %{_datadir}/polkit-1/actions/com.deepin.filemanager.daemon.policy
%{_datadir}/applications/dde-*.desktop
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/dbus-1/services/com.deepin.dde.desktop.service
%ifarch aarch64
%{_sysconfdir}/xdg/autostart/dde-file-manager-autostart.desktop
%endif

%files -n deepin-desktop
%defattr(-,root,root,-)
%{_bindir}/dde-desktop

%files -n lib%{_name}%{sover}
%defattr(-,root,root,-)
%{_libdir}/lib%{_name}.so.*

%files -n libdfm-extension%{sover}
%defattr(-,root,root,-)
%{_libdir}/libdfm-extension.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/%{_name}
%{_includedir}/dfm-extension
%{_libdir}/pkgconfig/*.pc
%{_libdir}/lib%{_name}.so
%{_libdir}/libdfm-extension.so

%files dbus
%defattr(-,root,root,-)
%{_bindir}/deepin-file-dbus-installer
%{_datadir}/%{_name}/dbus.tar.gz

%files polkit
%defattr(-,root,root,-)
%{_bindir}/deepin-file-polkit-installer
%{_datadir}/%{_name}/polkit.tar.gz

%files lang
%defattr(-,root,root,-)
%{_datadir}/dde-desktop
%{_datadir}/dde-disk-mount-plugin

%changelog
* Fri Sep 30 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix file list for %%arm
* Mon Sep 26 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Tumbleweed
* Tue Sep 20 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix filelist
* Wed Jun 29 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.6.4
  * Optimize text box length
  * Optimize draging for list mode
  * Fix bugs
  * Update translations
* Tue May 31 2022 Hillwood Yang <hillwood@opensuse.org>
- Add gcc-12.patch, fix gcc 12 build
* Mon Apr 18 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.10
  * Update documents
  * Fix bugs
* Thu Mar 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- No longer pin to GCC10: the code builds just fine using GCC11
  too, so let's use the distro default compiler.
* Tue Feb 22 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.3
  * Bring docparser
  * Update translations
  * Update manual documents
  * Fix bugs
- Drop fix-return-type-error.patch, fixed by upstream
* Thu Dec 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.1
  * Fix bugs
  * Update translations
  * Add new feature for document content: support markdown
* Fri Sep  3 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_dde-filemanager-daemon.service.patch
* Wed Jul 28 2021 Hillwood Yang <hillwood@opensuse.org>
- Update versiion to 5.2.24
  * Optimize ui
  * feat: a new disc burn mode which is compatible with windows' cd/dvd burn mode
  * Update manunal document
  * Fix bugs
* Mon Jun  7 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.2.18
  * Fix bugs
  * Add manual document
  * Change copyright
  * Update translations
- Drop 002-use-Q_GLOBAL_STATIC.patch, merged by upstream
- Drop disable-dmr.patch, enable dmr for arm
- Add fix-header-include.patch, dfsearch is necessary
* Wed Mar  3 2021 Hillwood Yang <hillwood@opensuse.org>
- Add 002-use-Q_GLOBAL_STATIC.patch. Fix segmentation fault
* Mon Feb 22 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.2.0.87
  * The fresh ui
  * Fix bugs
- Add fix-return-type-error.patch, fix return type for doctotext
- Drop Fix-redefinition-error.patch, merged by upstream
* Sat Jan 25 2020 Hillwood Yang <hillwood@opensuse.org>
- Add Fix-redefinition-error.patch
  * Fix redefinition of 'struct std::hash<QString>' error
* Mon Dec  2 2019 Hillwood Yang <hillwood@opensuse.org>
- Disable deepin movie plugin in ARM64. Add disable-dmr.patch
* Wed Jul 31 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.0
  * Fix redirect source urls before pasting them
  * Feat: block shutdown/sleep when there are paste event
  * Fix not check media if burn fails.
* Thu Jul 25 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.8.8.1
  * Support Qt 5.13
  * Fix crash at PropertyDialog
  * Add error message for insufficient disc space
  * Add image burning
* Sun Jul 14 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.8.6.4
  * Fix DFileDialog disable menu from titlebar
  * Fix typos in multiple DFMEvent subclasses
  * Fix copy dialog disable menu from titlebar
  * should remember auto merged status
  * should convert to QVariant first
  * should require auth
  * remove com.deepin.filemanager.daemon.policy
  * Fix several usb-device-formatter issues
  * lsar -J result changed after util-linux v2.33
  * Fix wallpaper geometry not updated after switching monitor configuration
  * merged desktop HiDPI icon blur
  * Fix redirect once for share panel in property dialog
  * update the geometry of the background widget before emit the
    backgroundGeometryChanged signal
  * Fix desktop icons obscured by dock if scaling is enabled ...
  * also try redirected URL for previewing
  * Fix dde-file-manager/dde-xdg-user-dirs-update set to executable
  * Fix crash if cannot found Delete menu action for Recent scheme
  * Fixdev-formatter: use customQtThemeConfigPathByUserHome()
  * Anything support disabled for non x86 arch
  * Fix desktop won't start when fileDialogOnly process exist
  * use customQtThemeConfigPathByUserHome()
  * Fix sidebar bookmark item cannot click after reorder
  * should no longer show virtual entry property dialog
  * Fix disk size sometimes can display negative number
  * Fix drag file to other app from mergeddesktop
  * Fix search keyword contains brackets
  * check if expand entry will make desktop full
  * pro: able to disable desktop shortcut and context menu
  * Fix hide indexing database in NTFS partition for Windows.
  * Fix loop call of update usershare
  * Fix debug build FTBFS.
  * should create fileinfo to get local file
  * always update mergeddesktop file data
  * Fix unable to access mtp mount device
  * Fix file mimetype results are not accurate on gvfs mount device
  * Update usershare info when getChildren
  * should create file info to get permissions
  * Fix typo in method name
  * Fix file permission error
  * Fix dde-desktop: the background window size and screen size are inconsistent
  * Fix temporary disable paste on merged desktop
  * workaround for merged desktop
  * Fix desktop widget hierarchy caused glitch
  * Fix avoid save profile when using merged desktop
  * Fix copy status not correct
  * Fix dde-wallpaper: find wallpaper thumbnails with no results
  * fileItemDisableFlag() for merged desktop
  * file watcher support for dfmmd scheme
  * Fix duplicated items from merged desktop controller
  * disable drag on merged desktop
  * Fixinvalid command args quotes for QProcess
  * Fixavoid crashing on file stat job
  * use plural for zero items
  * merge order caused compile error
  * The desktop background flash when the wallpaper is changed by user setting
  * Fix avoid crash in some case
  * using keyboard navigation causes wrong number of files in the status bar
  * Fix wrong number of items in disk properties dialog. (4c78d270)
  * Fix can open terminal under merged desktop scheme (9795c6eb)
  * Fix show hidden file on desktop not working (dd00701e)
  * list of recently used files empties unexpectedly.
  * right mouse button drag on virtual entry lead crash
  * Fix unknown mtime should show up properly now
  * disable desktop context menu for merged desktop mode
  * Fix desktop: will show titlebar in a short time
* Thu May  9 2019 Hillwood Yang <hillwood@opensuse.org>
- Remove invalid actions (boo#1134131)
* Sun Apr 21 2019 Hillwood Yang <hillwood@opensuse.org>
- Fix ui bug, set Requires tag for libqt5-dxcbplugin.
* Thu Apr 18 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.8.0
  * Fix also prompt the user to set executable bits for ELF files.
  * Fix crash on create file
  * Fix stray question mark in string.
  * Fix dialog: default button and recommend button not same
  * Merged desktop
  * Implement clear recent history
  * Fix can not close wallpaper settings view on click empty area
  * Fix zero size plain text file is not executable script
  * Fix the mode switch widget overlaps with other widgets
  * Fix file search view property dialog is empty
  * Fix dock mount plugin label content as plain text
  * Fix potential crash when an optical media is inserted.
  * Fix optical drive detection
  * Fix avoid crash when we cannot got device info
  * Fix Nothing on desktop in multi-screen and copy mode
  * Fix Desktop: use right-click menu when use window scale ratio, desktop will
    draw the content misplaced
  * Mount disk image
  * Context menu icon visible state now configurable
  * Fix crash when open systemdisk property
  * Fix use setPlainText for computer view items
  * Fix build error if enable DISABLE_ANYTHING
  * Fix MenuAction::Unknow is no longer the last one
  * Allowed find parent view mode
  * Fix user dirs changed to English in other DEs
  * Fix whel not working on ComputerView
  * Fix disk property display name not correct
  * Fix set proper working directory when running executables
  * Fix UI stuck when searching
  * Fix locker protect for handle xbel file changed
  * Use concurrent to handle recent file changed
  * Fix can't use anything for subdirectory
  * Fix user share dialog cannot open twice
  * Fix dde-file-manager: crash at getNodeByIndex
  * Fix dde-wallpaper: the mode switch widget overlaps with other widgets
  * Menu plugin can know menu is triggered on desktop
  * Read ~/.dde_env when run via pkexec
  * Add backup file type for deepin-clone
  * Support copy file on preview dialog
  * Get the search results with segment of quick search
  * Handle sigterm
  * The dde-wallpaper: support wallpaper slideshow
  * etc... Please view CHANGELOG.md to get more changes
* Wed Jan  9 2019 hillwood@opensuse.org
- Update version to 4.7.1.10
  * Use deepin-anything
  * Use new api of deepin-dock
  * Fix bugs
  * Update features
* Wed Mar 28 2018 hillwood@opensuse.org
- Update version to 4.4.8.3
  * Fix list all symlink files include broken symlink by QDirIterator
    with QDir::System
  * Fix can not restore trash files if target file is exist
  * Fix can not move the invalid symlink to trash
  * Fix check dock rect failed
  * Fix can not close computer property dialog  by CloseAllDialogIndicator
  * Fix the copy file dialog position is wrong when close
  * Prohibit file names from beginning or ending with spaces
* Thu Mar 22 2018 hillwood@opensuse.org
- Update version to 4.4.8.2
  * Fix bugs
  * Support preview the content files of dim file
  * Add "QIODevice *createIODevice()" for DAbstractFileInfo
  * Direct map filesystem to config file
  * Use env to debug
  * Support multi struct parial
  * Add swicth in dfm-platform to hide root system
  * Disbale unmount function in platform of x86 pro
  * Add build parameter BUILD_MINIMUM for live system
  * Add copy/cut/paste action in DFileDiloag
  * Add "monitorFiles" for dbus file dialog manager
  * Add function "windowFlags" for dbus file dialog
* Thu Nov 30 2017 hillwood@opensuse.org
- Update to 4.4.7
  * Many Features updated and Bugs fixed. Please See detail in CHANGELOG.md
* Tue Nov 14 2017 hillwood@opensuse.org
- Cleanup spec
  * Add Group tags.
  * Split libraries and language package.
  * Merge deepin-desktop in main package.
  * Use %%suse_update_desktop_file macro
  * Use %%fdupes macro
  * Update description for main package.
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
